@@ -1,5 +1,5 @@
 package Mail::DMARC::Report::Store::SQL::Grammars::MySQL;
-our $VERSION = '1.20250610';
+our $VERSION = '1.20260226';
 use strict;
 use warnings;
 
@@ -200,6 +200,17 @@ EO_REPORTS
     ;
 }
 
+sub count_filtered_report_query {
+    return <<'EO_SQL'
+SELECT COUNT(*)
+FROM report r
+LEFT JOIN author a  ON r.author_id=a.id
+LEFT JOIN domain fd ON r.from_domain_id=fd.id
+WHERE 1=1
+EO_SQL
+    ;
+}
+
 sub select_from {
     my ($self, $columns, $table) = @_;
     my $colStr = join( ', ', @$columns );
@@ -290,7 +301,7 @@ Mail::DMARC::Report::Store::SQL::Grammars::MySQL - Grammar for working with mysq
 
 =head1 VERSION
 
-version 1.20250610
+version 1.20260226
 
 =head1 SYPNOSIS
 
@@ -320,7 +331,7 @@ Marc Bradshaw <marc@marcbradshaw.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2025 by Matt Simerson.
+This software is copyright (c) 2026 by Matt Simerson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
